import React from 'react';
import { ViewProps } from 'react-native';
import { StyledComponentProps } from '../../theme';
interface ComponentProps extends ViewProps {
    animating?: boolean;
    size?: string;
    status?: string;
}
export declare type SpinnerProps = StyledComponentProps & ComponentProps;
export declare type SpinnerElement = React.ReactElement<SpinnerProps>;
/**
 * Styled `Spinner` component. Designed to be used as `ActivityIndicator` component
 *
 * @extends React.Component
 *
 * @property {boolean} animating - Determines whether component is animating. Default is `true`.
 *
 * @property {string} size - Determines the size of the component.
 * Can be `giant`, `large`, `medium`, `small` or `tiny`.
 * Default is `medium`.
 *
 * @property {string} status - Determines the status of the component.
 * Can be `primary`, `success`, `info`, `warning`, `danger` or `alternative`.
 * Default is `primary`.
 *
 * @overview-example SpinnerSimpleUsage
 *
 * @overview-example SpinnerSizes
 *
 * @overview-example SpinnerStatuses
 *
 * @example SpinnerDataLoading
 */
export declare class SpinnerComponent extends React.PureComponent<SpinnerProps> {
    static styledComponentName: string;
    static defaultProps: Partial<SpinnerProps>;
    private animation;
    private readonly containerSize;
    componentDidMount(): void;
    componentDidUpdate(prevProps: SpinnerProps): void;
    componentWillUnmount(): void;
    private startAnimation;
    private stopAnimation;
    private getComponentStyle;
    private renderArcElement;
    render(): React.ReactElement<ViewProps>;
}
export declare const Spinner: React.ComponentClass<SpinnerProps, any>;
export {};
